<a id="mypy-boto3-glue"></a>

# mypy-boto3-glue

[![PyPI - mypy-boto3-glue](https://img.shields.io/pypi/v/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-glue.svg?color=blue)](https://pypi.org/project/mypy-boto3-glue)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-glue?color=blue)](https://pypistats.org/packages/mypy-boto3-glue)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[boto3.Glue 1.26.13](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/glue.html#Glue)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.11.11](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-glue docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_glue/).

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [mypy-boto3-glue](#mypy-boto3-glue)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [How it works](#how-it-works)
  - [What's new](#what's-new)
    - [Implemented features](#implemented-features)
    - [Latest changes](#latest-changes)
  - [Versioning](#versioning)
  - [Thank you](#thank-you)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `Glue`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `boto3-stubs` for `Glue` service.

```bash
# install with boto3 type annotations
python -m pip install 'boto3-stubs[glue]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'boto3-stubs-lite[glue]'


# standalone installation
python -m pip install mypy-boto3-glue
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y mypy-boto3-glue
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto3-stubs[glue]` in your environment:

```bash
python -m pip install 'boto3-stubs[glue]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `boto3-stubs-lite[glue]` in your environment:

```bash
python -m pip install 'boto3-stubs-lite[glue]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `boto3-stubs` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `boto3-stubs` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[glue]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed `boto3-stubs`

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `boto3-stubs[glue]` with services you use in your environment:

```bash
python -m pip install 'boto3-stubs[glue]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto3-stubs[glue]` in your environment:

```bash
python -m pip install 'boto3-stubs[glue]'`
```

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `boto3-stubs[glue]` in your environment:

```bash
python -m pip install 'boto3-stubs[glue]'
```

Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`GlueClient` provides annotations for `boto3.client("glue")`.

```python
from boto3.session import Session

from mypy_boto3_glue import GlueClient

client: GlueClient = Session().client("glue")

# now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_glue.paginator` module contains type annotations for all
paginators.

```python
from boto3.session import Session

from mypy_boto3_glue import GlueClient
from mypy_boto3_glue.paginator import (
    GetClassifiersPaginator,
    GetConnectionsPaginator,
    GetCrawlerMetricsPaginator,
    GetCrawlersPaginator,
    GetDatabasesPaginator,
    GetDevEndpointsPaginator,
    GetJobRunsPaginator,
    GetJobsPaginator,
    GetPartitionIndexesPaginator,
    GetPartitionsPaginator,
    GetResourcePoliciesPaginator,
    GetSecurityConfigurationsPaginator,
    GetTableVersionsPaginator,
    GetTablesPaginator,
    GetTriggersPaginator,
    GetUserDefinedFunctionsPaginator,
    ListRegistriesPaginator,
    ListSchemaVersionsPaginator,
    ListSchemasPaginator,
)

client: GlueClient = Session().client("glue")

# Explicit type annotations are optional here
# Types should be correctly discovered by mypy and IDEs
get_classifiers_paginator: GetClassifiersPaginator = client.get_paginator("get_classifiers")
get_connections_paginator: GetConnectionsPaginator = client.get_paginator("get_connections")
get_crawler_metrics_paginator: GetCrawlerMetricsPaginator = client.get_paginator(
    "get_crawler_metrics"
)
get_crawlers_paginator: GetCrawlersPaginator = client.get_paginator("get_crawlers")
get_databases_paginator: GetDatabasesPaginator = client.get_paginator("get_databases")
get_dev_endpoints_paginator: GetDevEndpointsPaginator = client.get_paginator("get_dev_endpoints")
get_job_runs_paginator: GetJobRunsPaginator = client.get_paginator("get_job_runs")
get_jobs_paginator: GetJobsPaginator = client.get_paginator("get_jobs")
get_partition_indexes_paginator: GetPartitionIndexesPaginator = client.get_paginator(
    "get_partition_indexes"
)
get_partitions_paginator: GetPartitionsPaginator = client.get_paginator("get_partitions")
get_resource_policies_paginator: GetResourcePoliciesPaginator = client.get_paginator(
    "get_resource_policies"
)
get_security_configurations_paginator: GetSecurityConfigurationsPaginator = client.get_paginator(
    "get_security_configurations"
)
get_table_versions_paginator: GetTableVersionsPaginator = client.get_paginator("get_table_versions")
get_tables_paginator: GetTablesPaginator = client.get_paginator("get_tables")
get_triggers_paginator: GetTriggersPaginator = client.get_paginator("get_triggers")
get_user_defined_functions_paginator: GetUserDefinedFunctionsPaginator = client.get_paginator(
    "get_user_defined_functions"
)
list_registries_paginator: ListRegistriesPaginator = client.get_paginator("list_registries")
list_schema_versions_paginator: ListSchemaVersionsPaginator = client.get_paginator(
    "list_schema_versions"
)
list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
```

<a id="literals"></a>

### Literals

`mypy_boto3_glue.literals` module contains literals extracted from shapes that
can be used in user code for type checking.

```python
from mypy_boto3_glue.literals import (
    AggFunctionType,
    BackfillErrorCodeType,
    BlueprintRunStateType,
    BlueprintStatusType,
    CatalogEncryptionModeType,
    CloudWatchEncryptionModeType,
    ColumnStatisticsTypeType,
    ComparatorType,
    CompatibilityType,
    CompressionTypeType,
    ConnectionPropertyKeyType,
    ConnectionTypeType,
    CrawlStateType,
    CrawlerHistoryStateType,
    CrawlerLineageSettingsType,
    CrawlerStateType,
    CsvHeaderOptionType,
    DataFormatType,
    DeleteBehaviorType,
    EnableHybridValuesType,
    ExecutionClassType,
    ExistConditionType,
    FieldNameType,
    FilterLogicalOperatorType,
    FilterOperationType,
    FilterOperatorType,
    FilterValueTypeType,
    GetClassifiersPaginatorName,
    GetConnectionsPaginatorName,
    GetCrawlerMetricsPaginatorName,
    GetCrawlersPaginatorName,
    GetDatabasesPaginatorName,
    GetDevEndpointsPaginatorName,
    GetJobRunsPaginatorName,
    GetJobsPaginatorName,
    GetPartitionIndexesPaginatorName,
    GetPartitionsPaginatorName,
    GetResourcePoliciesPaginatorName,
    GetSecurityConfigurationsPaginatorName,
    GetTableVersionsPaginatorName,
    GetTablesPaginatorName,
    GetTriggersPaginatorName,
    GetUserDefinedFunctionsPaginatorName,
    GlueRecordTypeType,
    JDBCDataTypeType,
    JdbcMetadataEntryType,
    JobBookmarksEncryptionModeType,
    JobRunStateType,
    JoinTypeType,
    LanguageType,
    LastCrawlStatusType,
    ListRegistriesPaginatorName,
    ListSchemaVersionsPaginatorName,
    ListSchemasPaginatorName,
    LogicalOperatorType,
    LogicalType,
    MLUserDataEncryptionModeStringType,
    NodeTypeType,
    ParquetCompressionTypeType,
    PartitionIndexStatusType,
    PermissionType,
    PermissionTypeType,
    PiiTypeType,
    PrincipalTypeType,
    QuoteCharType,
    RecrawlBehaviorType,
    RegistryStatusType,
    ResourceShareTypeType,
    ResourceTypeType,
    S3EncryptionModeType,
    ScheduleStateType,
    SchemaDiffTypeType,
    SchemaStatusType,
    SchemaVersionStatusType,
    SeparatorType,
    SessionStatusType,
    SortDirectionTypeType,
    SortType,
    SourceControlAuthStrategyType,
    SourceControlProviderType,
    StartingPositionType,
    StatementStateType,
    TargetFormatType,
    TaskRunSortColumnTypeType,
    TaskStatusTypeType,
    TaskTypeType,
    TransformSortColumnTypeType,
    TransformStatusTypeType,
    TransformTypeType,
    TriggerStateType,
    TriggerTypeType,
    UnionTypeType,
    UpdateBehaviorType,
    UpdateCatalogBehaviorType,
    WorkerTypeType,
    WorkflowRunStatusType,
    GlueServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)


def check_value(value: AggFunctionType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_glue.type_defs` module contains structures and shapes assembled to
typed dictionaries for additional type checking.

```python
from mypy_boto3_glue.type_defs import (
    NotificationPropertyTypeDef,
    AggregateOperationTypeDef,
    ApplyMappingTypeDef,
    AuditContextTypeDef,
    PartitionValueListTypeDef,
    BasicCatalogTargetTypeDef,
    ResponseMetadataTypeDef,
    BatchDeleteConnectionRequestRequestTypeDef,
    ErrorDetailTypeDef,
    BatchDeleteTableRequestRequestTypeDef,
    BatchDeleteTableVersionRequestRequestTypeDef,
    BatchGetBlueprintsRequestRequestTypeDef,
    BatchGetCrawlersRequestRequestTypeDef,
    BatchGetCustomEntityTypesRequestRequestTypeDef,
    CustomEntityTypeTypeDef,
    BatchGetDevEndpointsRequestRequestTypeDef,
    DevEndpointTypeDef,
    BatchGetJobsRequestRequestTypeDef,
    BatchGetTriggersRequestRequestTypeDef,
    BatchGetWorkflowsRequestRequestTypeDef,
    BatchStopJobRunRequestRequestTypeDef,
    BatchStopJobRunSuccessfulSubmissionTypeDef,
    BinaryColumnStatisticsDataTypeDef,
    BlueprintDetailsTypeDef,
    BlueprintRunTypeDef,
    LastActiveDefinitionTypeDef,
    BooleanColumnStatisticsDataTypeDef,
    CancelMLTaskRunRequestRequestTypeDef,
    CancelStatementRequestRequestTypeDef,
    CatalogEntryTypeDef,
    CatalogImportStatusTypeDef,
    KafkaStreamingSourceOptionsTypeDef,
    StreamingDataPreviewOptionsTypeDef,
    KinesisStreamingSourceOptionsTypeDef,
    CatalogSchemaChangePolicyTypeDef,
    CatalogSourceTypeDef,
    CatalogTargetTypeDef,
    CheckSchemaVersionValidityInputRequestTypeDef,
    CsvClassifierTypeDef,
    GrokClassifierTypeDef,
    JsonClassifierTypeDef,
    XMLClassifierTypeDef,
    CloudWatchEncryptionTypeDef,
    DropDuplicatesTypeDef,
    DropFieldsTypeDef,
    DynamoDBCatalogSourceTypeDef,
    FillMissingValuesTypeDef,
    MergeTypeDef,
    MicrosoftSQLServerCatalogSourceTypeDef,
    MicrosoftSQLServerCatalogTargetTypeDef,
    MySQLCatalogSourceTypeDef,
    MySQLCatalogTargetTypeDef,
    OracleSQLCatalogSourceTypeDef,
    OracleSQLCatalogTargetTypeDef,
    PIIDetectionTypeDef,
    PostgreSQLCatalogSourceTypeDef,
    PostgreSQLCatalogTargetTypeDef,
    RedshiftSourceTypeDef,
    RelationalCatalogSourceTypeDef,
    RenameFieldTypeDef,
    SelectFieldsTypeDef,
    SelectFromCollectionTypeDef,
    SpigotTypeDef,
    SplitFieldsTypeDef,
    UnionTypeDef,
    CodeGenEdgeTypeDef,
    CodeGenNodeArgTypeDef,
    ColumnImportanceTypeDef,
    ColumnRowFilterTypeDef,
    DateColumnStatisticsDataTypeDef,
    DoubleColumnStatisticsDataTypeDef,
    LongColumnStatisticsDataTypeDef,
    StringColumnStatisticsDataTypeDef,
    ColumnTypeDef,
    ConditionTypeDef,
    ConfusionMatrixTypeDef,
    PhysicalConnectionRequirementsTypeDef,
    ConnectionPasswordEncryptionTypeDef,
    ConnectionsListTypeDef,
    CrawlTypeDef,
    CrawlerHistoryTypeDef,
    CrawlerMetricsTypeDef,
    DeltaTargetTypeDef,
    DynamoDBTargetTypeDef,
    JdbcTargetTypeDef,
    MongoDBTargetTypeDef,
    S3TargetTypeDef,
    LakeFormationConfigurationTypeDef,
    LastCrawlInfoTypeDef,
    LineageConfigurationTypeDef,
    RecrawlPolicyTypeDef,
    ScheduleTypeDef,
    SchemaChangePolicyTypeDef,
    CrawlsFilterTypeDef,
    CreateBlueprintRequestRequestTypeDef,
    CreateCsvClassifierRequestTypeDef,
    CreateGrokClassifierRequestTypeDef,
    CreateJsonClassifierRequestTypeDef,
    CreateXMLClassifierRequestTypeDef,
    CreateCustomEntityTypeRequestRequestTypeDef,
    CreateDevEndpointRequestRequestTypeDef,
    ExecutionPropertyTypeDef,
    JobCommandTypeDef,
    SourceControlDetailsTypeDef,
    GlueTableTypeDef,
    PartitionIndexTypeDef,
    CreateRegistryInputRequestTypeDef,
    RegistryIdTypeDef,
    SessionCommandTypeDef,
    EventBatchingConditionTypeDef,
    CreateWorkflowRequestRequestTypeDef,
    EncryptionAtRestTypeDef,
    DataLakePrincipalTypeDef,
    DatabaseIdentifierTypeDef,
    DatatypeTypeDef,
    DecimalNumberTypeDef,
    DeleteBlueprintRequestRequestTypeDef,
    DeleteClassifierRequestRequestTypeDef,
    DeleteColumnStatisticsForPartitionRequestRequestTypeDef,
    DeleteColumnStatisticsForTableRequestRequestTypeDef,
    DeleteConnectionRequestRequestTypeDef,
    DeleteCrawlerRequestRequestTypeDef,
    DeleteCustomEntityTypeRequestRequestTypeDef,
    DeleteDatabaseRequestRequestTypeDef,
    DeleteDevEndpointRequestRequestTypeDef,
    DeleteJobRequestRequestTypeDef,
    DeleteMLTransformRequestRequestTypeDef,
    DeletePartitionIndexRequestRequestTypeDef,
    DeletePartitionRequestRequestTypeDef,
    DeleteResourcePolicyRequestRequestTypeDef,
    SchemaIdTypeDef,
    DeleteSecurityConfigurationRequestRequestTypeDef,
    DeleteSessionRequestRequestTypeDef,
    DeleteTableRequestRequestTypeDef,
    DeleteTableVersionRequestRequestTypeDef,
    DeleteTriggerRequestRequestTypeDef,
    DeleteUserDefinedFunctionRequestRequestTypeDef,
    DeleteWorkflowRequestRequestTypeDef,
    DevEndpointCustomLibrariesTypeDef,
    DirectSchemaChangePolicyTypeDef,
    NullCheckBoxListTypeDef,
    EdgeTypeDef,
    JobBookmarksEncryptionTypeDef,
    S3EncryptionTypeDef,
    ErrorDetailsTypeDef,
    ExportLabelsTaskRunPropertiesTypeDef,
    FilterValueTypeDef,
    FindMatchesParametersTypeDef,
    FindMatchesTaskRunPropertiesTypeDef,
    GetBlueprintRequestRequestTypeDef,
    GetBlueprintRunRequestRequestTypeDef,
    GetBlueprintRunsRequestRequestTypeDef,
    GetCatalogImportStatusRequestRequestTypeDef,
    GetClassifierRequestRequestTypeDef,
    PaginatorConfigTypeDef,
    GetClassifiersRequestRequestTypeDef,
    GetColumnStatisticsForPartitionRequestRequestTypeDef,
    GetColumnStatisticsForTableRequestRequestTypeDef,
    GetConnectionRequestRequestTypeDef,
    GetConnectionsFilterTypeDef,
    GetCrawlerMetricsRequestRequestTypeDef,
    GetCrawlerRequestRequestTypeDef,
    GetCrawlersRequestRequestTypeDef,
    GetCustomEntityTypeRequestRequestTypeDef,
    GetDataCatalogEncryptionSettingsRequestRequestTypeDef,
    GetDatabaseRequestRequestTypeDef,
    GetDatabasesRequestRequestTypeDef,
    GetDataflowGraphRequestRequestTypeDef,
    GetDevEndpointRequestRequestTypeDef,
    GetDevEndpointsRequestRequestTypeDef,
    GetJobBookmarkRequestRequestTypeDef,
    JobBookmarkEntryTypeDef,
    GetJobRequestRequestTypeDef,
    GetJobRunRequestRequestTypeDef,
    GetJobRunsRequestRequestTypeDef,
    GetJobsRequestRequestTypeDef,
    GetMLTaskRunRequestRequestTypeDef,
    TaskRunFilterCriteriaTypeDef,
    TaskRunSortCriteriaTypeDef,
    GetMLTransformRequestRequestTypeDef,
    SchemaColumnTypeDef,
    TransformSortCriteriaTypeDef,
    MappingEntryTypeDef,
    GetPartitionIndexesRequestRequestTypeDef,
    GetPartitionRequestRequestTypeDef,
    SegmentTypeDef,
    GetResourcePoliciesRequestRequestTypeDef,
    GluePolicyTypeDef,
    GetResourcePolicyRequestRequestTypeDef,
    SchemaVersionNumberTypeDef,
    GetSecurityConfigurationRequestRequestTypeDef,
    GetSecurityConfigurationsRequestRequestTypeDef,
    GetSessionRequestRequestTypeDef,
    GetStatementRequestRequestTypeDef,
    GetTableRequestRequestTypeDef,
    GetTableVersionRequestRequestTypeDef,
    GetTableVersionsRequestRequestTypeDef,
    GetTablesRequestRequestTypeDef,
    GetTagsRequestRequestTypeDef,
    GetTriggerRequestRequestTypeDef,
    GetTriggersRequestRequestTypeDef,
    GetUserDefinedFunctionRequestRequestTypeDef,
    GetUserDefinedFunctionsRequestRequestTypeDef,
    GetWorkflowRequestRequestTypeDef,
    GetWorkflowRunPropertiesRequestRequestTypeDef,
    GetWorkflowRunRequestRequestTypeDef,
    GetWorkflowRunsRequestRequestTypeDef,
    GlueStudioSchemaColumnTypeDef,
    S3SourceAdditionalOptionsTypeDef,
    ImportCatalogToGlueRequestRequestTypeDef,
    ImportLabelsTaskRunPropertiesTypeDef,
    JDBCConnectorOptionsTypeDef,
    PredecessorTypeDef,
    JoinColumnTypeDef,
    KeySchemaElementTypeDef,
    LabelingSetGenerationTaskRunPropertiesTypeDef,
    ListBlueprintsRequestRequestTypeDef,
    ListCrawlersRequestRequestTypeDef,
    ListCustomEntityTypesRequestRequestTypeDef,
    ListDevEndpointsRequestRequestTypeDef,
    ListJobsRequestRequestTypeDef,
    ListRegistriesInputRequestTypeDef,
    RegistryListItemTypeDef,
    SchemaVersionListItemTypeDef,
    SchemaListItemTypeDef,
    ListSessionsRequestRequestTypeDef,
    ListStatementsRequestRequestTypeDef,
    ListTriggersRequestRequestTypeDef,
    ListWorkflowsRequestRequestTypeDef,
    MLUserDataEncryptionTypeDef,
    MappingTypeDef,
    OtherMetadataValueListItemTypeDef,
    MetadataKeyValuePairTypeDef,
    OrderTypeDef,
    PropertyPredicateTypeDef,
    PutResourcePolicyRequestRequestTypeDef,
    PutWorkflowRunPropertiesRequestRequestTypeDef,
    UpsertRedshiftTargetOptionsTypeDef,
    ResetJobBookmarkRequestRequestTypeDef,
    ResourceUriTypeDef,
    ResumeWorkflowRunRequestRequestTypeDef,
    RunStatementRequestRequestTypeDef,
    S3DirectSourceAdditionalOptionsTypeDef,
    SortCriterionTypeDef,
    SerDeInfoTypeDef,
    SkewedInfoTypeDef,
    SqlAliasTypeDef,
    StartBlueprintRunRequestRequestTypeDef,
    StartCrawlerRequestRequestTypeDef,
    StartCrawlerScheduleRequestRequestTypeDef,
    StartExportLabelsTaskRunRequestRequestTypeDef,
    StartImportLabelsTaskRunRequestRequestTypeDef,
    StartMLEvaluationTaskRunRequestRequestTypeDef,
    StartMLLabelingSetGenerationTaskRunRequestRequestTypeDef,
    StartTriggerRequestRequestTypeDef,
    StartWorkflowRunRequestRequestTypeDef,
    StartingEventBatchConditionTypeDef,
    StatementOutputDataTypeDef,
    StopCrawlerRequestRequestTypeDef,
    StopCrawlerScheduleRequestRequestTypeDef,
    StopSessionRequestRequestTypeDef,
    StopTriggerRequestRequestTypeDef,
    StopWorkflowRunRequestRequestTypeDef,
    TableIdentifierTypeDef,
    TagResourceRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateBlueprintRequestRequestTypeDef,
    UpdateCsvClassifierRequestTypeDef,
    UpdateGrokClassifierRequestTypeDef,
    UpdateJsonClassifierRequestTypeDef,
    UpdateXMLClassifierRequestTypeDef,
    UpdateCrawlerScheduleRequestRequestTypeDef,
    UpdateJobFromSourceControlRequestRequestTypeDef,
    UpdateSourceControlFromJobRequestRequestTypeDef,
    UpdateWorkflowRequestRequestTypeDef,
    WorkflowRunStatisticsTypeDef,
    ActionTypeDef,
    StartJobRunRequestRequestTypeDef,
    AggregateTypeDef,
    GetUnfilteredPartitionMetadataRequestRequestTypeDef,
    GetUnfilteredTableMetadataRequestRequestTypeDef,
    BackfillErrorTypeDef,
    BatchDeletePartitionRequestRequestTypeDef,
    BatchGetPartitionRequestRequestTypeDef,
    CancelMLTaskRunResponseTypeDef,
    CheckSchemaVersionValidityResponseTypeDef,
    CreateBlueprintResponseTypeDef,
    CreateCustomEntityTypeResponseTypeDef,
    CreateDevEndpointResponseTypeDef,
    CreateJobResponseTypeDef,
    CreateMLTransformResponseTypeDef,
    CreateRegistryResponseTypeDef,
    CreateSchemaResponseTypeDef,
    CreateScriptResponseTypeDef,
    CreateSecurityConfigurationResponseTypeDef,
    CreateTriggerResponseTypeDef,
    CreateWorkflowResponseTypeDef,
    DeleteBlueprintResponseTypeDef,
    DeleteCustomEntityTypeResponseTypeDef,
    DeleteJobResponseTypeDef,
    DeleteMLTransformResponseTypeDef,
    DeleteRegistryResponseTypeDef,
    DeleteSchemaResponseTypeDef,
    DeleteSessionResponseTypeDef,
    DeleteTriggerResponseTypeDef,
    DeleteWorkflowResponseTypeDef,
    GetCustomEntityTypeResponseTypeDef,
    GetPlanResponseTypeDef,
    GetRegistryResponseTypeDef,
    GetResourcePolicyResponseTypeDef,
    GetSchemaByDefinitionResponseTypeDef,
    GetSchemaResponseTypeDef,
    GetSchemaVersionResponseTypeDef,
    GetSchemaVersionsDiffResponseTypeDef,
    GetTagsResponseTypeDef,
    GetWorkflowRunPropertiesResponseTypeDef,
    ListBlueprintsResponseTypeDef,
    ListCrawlersResponseTypeDef,
    ListDevEndpointsResponseTypeDef,
    ListJobsResponseTypeDef,
    ListMLTransformsResponseTypeDef,
    ListTriggersResponseTypeDef,
    ListWorkflowsResponseTypeDef,
    PutResourcePolicyResponseTypeDef,
    PutSchemaVersionMetadataResponseTypeDef,
    RegisterSchemaVersionResponseTypeDef,
    RemoveSchemaVersionMetadataResponseTypeDef,
    ResumeWorkflowRunResponseTypeDef,
    RunStatementResponseTypeDef,
    StartBlueprintRunResponseTypeDef,
    StartExportLabelsTaskRunResponseTypeDef,
    StartImportLabelsTaskRunResponseTypeDef,
    StartJobRunResponseTypeDef,
    StartMLEvaluationTaskRunResponseTypeDef,
    StartMLLabelingSetGenerationTaskRunResponseTypeDef,
    StartTriggerResponseTypeDef,
    StartWorkflowRunResponseTypeDef,
    StopSessionResponseTypeDef,
    StopTriggerResponseTypeDef,
    UpdateBlueprintResponseTypeDef,
    UpdateJobFromSourceControlResponseTypeDef,
    UpdateJobResponseTypeDef,
    UpdateMLTransformResponseTypeDef,
    UpdateRegistryResponseTypeDef,
    UpdateSchemaResponseTypeDef,
    UpdateSourceControlFromJobResponseTypeDef,
    UpdateWorkflowResponseTypeDef,
    BatchDeleteConnectionResponseTypeDef,
    BatchStopJobRunErrorTypeDef,
    BatchUpdatePartitionFailureEntryTypeDef,
    ColumnErrorTypeDef,
    PartitionErrorTypeDef,
    TableErrorTypeDef,
    TableVersionErrorTypeDef,
    BatchGetCustomEntityTypesResponseTypeDef,
    ListCustomEntityTypesResponseTypeDef,
    BatchGetDevEndpointsResponseTypeDef,
    GetDevEndpointResponseTypeDef,
    GetDevEndpointsResponseTypeDef,
    GetBlueprintRunResponseTypeDef,
    GetBlueprintRunsResponseTypeDef,
    BlueprintTypeDef,
    GetCatalogImportStatusResponseTypeDef,
    CatalogKafkaSourceTypeDef,
    DirectKafkaSourceTypeDef,
    CatalogKinesisSourceTypeDef,
    DirectKinesisSourceTypeDef,
    GovernedCatalogTargetTypeDef,
    S3CatalogTargetTypeDef,
    ClassifierTypeDef,
    CodeGenNodeTypeDef,
    LocationTypeDef,
    PredicateTypeDef,
    FindMatchesMetricsTypeDef,
    ConnectionInputTypeDef,
    ConnectionTypeDef,
    CrawlerNodeDetailsTypeDef,
    ListCrawlsResponseTypeDef,
    GetCrawlerMetricsResponseTypeDef,
    CrawlerTargetsTypeDef,
    ListCrawlsRequestRequestTypeDef,
    CreateClassifierRequestRequestTypeDef,
    CreatePartitionIndexRequestRequestTypeDef,
    CreateSchemaInputRequestTypeDef,
    DeleteRegistryInputRequestTypeDef,
    GetRegistryInputRequestTypeDef,
    ListSchemasInputRequestTypeDef,
    UpdateRegistryInputRequestTypeDef,
    CreateSessionRequestRequestTypeDef,
    SessionTypeDef,
    DataCatalogEncryptionSettingsTypeDef,
    PrincipalPermissionsTypeDef,
    NullValueFieldTypeDef,
    DecimalColumnStatisticsDataTypeDef,
    DeleteSchemaInputRequestTypeDef,
    DeleteSchemaVersionsInputRequestTypeDef,
    GetSchemaByDefinitionInputRequestTypeDef,
    GetSchemaInputRequestTypeDef,
    ListSchemaVersionsInputRequestTypeDef,
    RegisterSchemaVersionInputRequestTypeDef,
    SchemaReferenceTypeDef,
    UpdateDevEndpointRequestRequestTypeDef,
    S3DirectTargetTypeDef,
    S3GlueParquetTargetTypeDef,
    EncryptionConfigurationTypeDef,
    SchemaVersionErrorItemTypeDef,
    FilterExpressionTypeDef,
    TransformParametersTypeDef,
    GetClassifiersRequestGetClassifiersPaginateTypeDef,
    GetCrawlerMetricsRequestGetCrawlerMetricsPaginateTypeDef,
    GetCrawlersRequestGetCrawlersPaginateTypeDef,
    GetDatabasesRequestGetDatabasesPaginateTypeDef,
    GetDevEndpointsRequestGetDevEndpointsPaginateTypeDef,
    GetJobRunsRequestGetJobRunsPaginateTypeDef,
    GetJobsRequestGetJobsPaginateTypeDef,
    GetPartitionIndexesRequestGetPartitionIndexesPaginateTypeDef,
    GetResourcePoliciesRequestGetResourcePoliciesPaginateTypeDef,
    GetSecurityConfigurationsRequestGetSecurityConfigurationsPaginateTypeDef,
    GetTableVersionsRequestGetTableVersionsPaginateTypeDef,
    GetTablesRequestGetTablesPaginateTypeDef,
    GetTriggersRequestGetTriggersPaginateTypeDef,
    GetUserDefinedFunctionsRequestGetUserDefinedFunctionsPaginateTypeDef,
    ListRegistriesInputListRegistriesPaginateTypeDef,
    ListSchemaVersionsInputListSchemaVersionsPaginateTypeDef,
    ListSchemasInputListSchemasPaginateTypeDef,
    GetConnectionsRequestGetConnectionsPaginateTypeDef,
    GetConnectionsRequestRequestTypeDef,
    GetJobBookmarkResponseTypeDef,
    ResetJobBookmarkResponseTypeDef,
    GetMLTaskRunsRequestRequestTypeDef,
    TransformFilterCriteriaTypeDef,
    GetMappingResponseTypeDef,
    GetPartitionsRequestGetPartitionsPaginateTypeDef,
    GetPartitionsRequestRequestTypeDef,
    GetUnfilteredPartitionsMetadataRequestRequestTypeDef,
    GetResourcePoliciesResponseTypeDef,
    GetSchemaVersionInputRequestTypeDef,
    GetSchemaVersionsDiffInputRequestTypeDef,
    UpdateSchemaInputRequestTypeDef,
    GlueSchemaTypeDef,
    GovernedCatalogSourceTypeDef,
    S3CatalogSourceTypeDef,
    JobRunTypeDef,
    JoinTypeDef,
    TaskRunPropertiesTypeDef,
    ListRegistriesResponseTypeDef,
    ListSchemaVersionsResponseTypeDef,
    ListSchemasResponseTypeDef,
    TransformEncryptionTypeDef,
    MetadataInfoTypeDef,
    PutSchemaVersionMetadataInputRequestTypeDef,
    QuerySchemaVersionMetadataInputRequestTypeDef,
    RemoveSchemaVersionMetadataInputRequestTypeDef,
    RedshiftTargetTypeDef,
    UserDefinedFunctionInputTypeDef,
    UserDefinedFunctionTypeDef,
    SearchTablesRequestRequestTypeDef,
    StatementOutputTypeDef,
    UpdateClassifierRequestRequestTypeDef,
    PartitionIndexDescriptorTypeDef,
    BatchStopJobRunResponseTypeDef,
    BatchUpdatePartitionResponseTypeDef,
    BatchCreatePartitionResponseTypeDef,
    BatchDeletePartitionResponseTypeDef,
    BatchDeleteTableResponseTypeDef,
    BatchDeleteTableVersionResponseTypeDef,
    BatchGetBlueprintsResponseTypeDef,
    GetBlueprintResponseTypeDef,
    GetClassifierResponseTypeDef,
    GetClassifiersResponseTypeDef,
    CreateScriptRequestRequestTypeDef,
    GetDataflowGraphResponseTypeDef,
    GetMappingRequestRequestTypeDef,
    GetPlanRequestRequestTypeDef,
    CreateTriggerRequestRequestTypeDef,
    TriggerTypeDef,
    TriggerUpdateTypeDef,
    EvaluationMetricsTypeDef,
    CreateConnectionRequestRequestTypeDef,
    UpdateConnectionRequestRequestTypeDef,
    GetConnectionResponseTypeDef,
    GetConnectionsResponseTypeDef,
    CrawlerTypeDef,
    CreateCrawlerRequestRequestTypeDef,
    UpdateCrawlerRequestRequestTypeDef,
    CreateSessionResponseTypeDef,
    GetSessionResponseTypeDef,
    ListSessionsResponseTypeDef,
    GetDataCatalogEncryptionSettingsResponseTypeDef,
    PutDataCatalogEncryptionSettingsRequestRequestTypeDef,
    DatabaseInputTypeDef,
    DatabaseTypeDef,
    DropNullFieldsTypeDef,
    ColumnStatisticsDataTypeDef,
    StorageDescriptorTypeDef,
    CreateSecurityConfigurationRequestRequestTypeDef,
    SecurityConfigurationTypeDef,
    DeleteSchemaVersionsResponseTypeDef,
    FilterTypeDef,
    UpdateMLTransformRequestRequestTypeDef,
    GetMLTransformsRequestRequestTypeDef,
    ListMLTransformsRequestRequestTypeDef,
    AthenaConnectorSourceTypeDef,
    CustomCodeTypeDef,
    JDBCConnectorSourceTypeDef,
    JDBCConnectorTargetTypeDef,
    S3CsvSourceTypeDef,
    S3JsonSourceTypeDef,
    S3ParquetSourceTypeDef,
    SparkConnectorSourceTypeDef,
    SparkConnectorTargetTypeDef,
    SparkSQLTypeDef,
    GetJobRunResponseTypeDef,
    GetJobRunsResponseTypeDef,
    JobNodeDetailsTypeDef,
    GetMLTaskRunResponseTypeDef,
    TaskRunTypeDef,
    CreateMLTransformRequestRequestTypeDef,
    QuerySchemaVersionMetadataResponseTypeDef,
    CreateUserDefinedFunctionRequestRequestTypeDef,
    UpdateUserDefinedFunctionRequestRequestTypeDef,
    GetUserDefinedFunctionResponseTypeDef,
    GetUserDefinedFunctionsResponseTypeDef,
    StatementTypeDef,
    GetPartitionIndexesResponseTypeDef,
    BatchGetTriggersResponseTypeDef,
    GetTriggerResponseTypeDef,
    GetTriggersResponseTypeDef,
    TriggerNodeDetailsTypeDef,
    UpdateTriggerResponseTypeDef,
    UpdateTriggerRequestRequestTypeDef,
    GetMLTransformResponseTypeDef,
    MLTransformTypeDef,
    BatchGetCrawlersResponseTypeDef,
    GetCrawlerResponseTypeDef,
    GetCrawlersResponseTypeDef,
    CreateDatabaseRequestRequestTypeDef,
    UpdateDatabaseRequestRequestTypeDef,
    GetDatabaseResponseTypeDef,
    GetDatabasesResponseTypeDef,
    ColumnStatisticsTypeDef,
    PartitionInputTypeDef,
    PartitionTypeDef,
    TableInputTypeDef,
    TableTypeDef,
    GetSecurityConfigurationResponseTypeDef,
    GetSecurityConfigurationsResponseTypeDef,
    CodeGenConfigurationNodeTypeDef,
    GetMLTaskRunsResponseTypeDef,
    GetStatementResponseTypeDef,
    ListStatementsResponseTypeDef,
    NodeTypeDef,
    GetMLTransformsResponseTypeDef,
    ColumnStatisticsErrorTypeDef,
    GetColumnStatisticsForPartitionResponseTypeDef,
    GetColumnStatisticsForTableResponseTypeDef,
    UpdateColumnStatisticsForPartitionRequestRequestTypeDef,
    UpdateColumnStatisticsForTableRequestRequestTypeDef,
    BatchCreatePartitionRequestRequestTypeDef,
    BatchUpdatePartitionRequestEntryTypeDef,
    CreatePartitionRequestRequestTypeDef,
    UpdatePartitionRequestRequestTypeDef,
    BatchGetPartitionResponseTypeDef,
    GetPartitionResponseTypeDef,
    GetPartitionsResponseTypeDef,
    GetUnfilteredPartitionMetadataResponseTypeDef,
    UnfilteredPartitionTypeDef,
    CreateTableRequestRequestTypeDef,
    UpdateTableRequestRequestTypeDef,
    GetTableResponseTypeDef,
    GetTablesResponseTypeDef,
    GetUnfilteredTableMetadataResponseTypeDef,
    SearchTablesResponseTypeDef,
    TableVersionTypeDef,
    CreateJobRequestRequestTypeDef,
    JobTypeDef,
    JobUpdateTypeDef,
    WorkflowGraphTypeDef,
    UpdateColumnStatisticsForPartitionResponseTypeDef,
    UpdateColumnStatisticsForTableResponseTypeDef,
    BatchUpdatePartitionRequestRequestTypeDef,
    GetUnfilteredPartitionsMetadataResponseTypeDef,
    GetTableVersionResponseTypeDef,
    GetTableVersionsResponseTypeDef,
    BatchGetJobsResponseTypeDef,
    GetJobResponseTypeDef,
    GetJobsResponseTypeDef,
    UpdateJobRequestRequestTypeDef,
    WorkflowRunTypeDef,
    GetWorkflowRunResponseTypeDef,
    GetWorkflowRunsResponseTypeDef,
    WorkflowTypeDef,
    BatchGetWorkflowsResponseTypeDef,
    GetWorkflowResponseTypeDef,
)


def get_structure() -> NotificationPropertyTypeDef:
    return {...}
```

<a id="how-it-works"></a>

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for `boto3`
updates. It delivers a drop-in type annotations for you and makes sure that:

- All available `boto3` services are covered.
- Each public class and method of every `boto3` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

<a id="what's-new"></a>

## What's new

<a id="implemented-features"></a>

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

<a id="latest-changes"></a>

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

<a id="versioning"></a>

## Versioning

`mypy-boto3-glue` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="thank-you"></a>

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

<a id="documentation"></a>

## Documentation

All services type annotations can be found in
[boto3 docs](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_glue/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
